# RedPlanet documentation

## Project layout

```bash
mkdocs.yml    # The configuration file.
src/
    index.md  # The documentation homepage.
    ...       # Other markdown pages
```

## Commands

- `just site-serve` — Start the live-reloading docs server locally (see: http://localhost:8000/ ).
- `just site-deploy` — Deploy to GitHub Pages.
